==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-move-tab-action.js <==
import { __extends } from "tslib";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { IgrPaneDragAction } from "./igr-pane-drag-action";
import { MoveTabAction } from "./MoveTabAction";
import { ensureEnum } from "igniteui-react-core";
var IgrMoveTabAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrMoveTabAction, _super);
    function IgrMoveTabAction(props) {
        return _super.call(this, props) || this;
    }
    IgrMoveTabAction.prototype.createImplementation = function () {
        return new MoveTabAction();
    };
    Object.defineProperty(IgrMoveTabAction.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveTabAction.prototype, "actionType", {
        get: function () {
            return this.i.a;
        },
        set: function (v) {
            this.i.a = ensureEnum(PaneDragActionType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveTabAction.prototype, "oldIndex", {
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveTabAction.prototype, "newIndex", {
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrMoveTabAction;
}(IgrPaneDragAction));
export { IgrMoveTabAction };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-move-tab-action.js <==
import { __extends } from "tslib";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { IgrPaneDragAction } from "./igr-pane-drag-action";
import { MoveTabAction } from "./MoveTabAction";
import { ensureEnum } from "igniteui-react-core";
var IgrMoveTabAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrMoveTabAction, _super);
    function IgrMoveTabAction(props) {
        return _super.call(this, props) || this;
    }
    IgrMoveTabAction.prototype.createImplementation = function () {
        return new MoveTabAction();
    };
    Object.defineProperty(IgrMoveTabAction.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveTabAction.prototype, "type", {
        get: function () {
            return this.i.a;
        },
        set: function (v) {
            this.i.a = ensureEnum(PaneDragActionType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveTabAction.prototype, "oldIndex", {
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMoveTabAction.prototype, "newIndex", {
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgrMoveTabAction.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    return IgrMoveTabAction;
}(IgrPaneDragAction));
export { IgrMoveTabAction };
